@@ -26,7 +26,7 @@ package goamdsmi
 /*
 #cgo CFLAGS: -Wall -I/opt/rocm/include
 #cgo LDFLAGS: -L/opt/rocm/lib -L/opt/rocm/lib64 -lgoamdsmi_shim64 -Wl,--unresolved-symbols=ignore-in-object-files
-#include <stdint.h>
+#include <cstdint>
 #include <amdsmi_go_shim.h>
 */
 import "C"
